@@ -181,8 +181,8 @@ class ReplaceMatcher:
                 try:
                     refd_tokens = pattern_ref[ref]
                     if len(refd_tokens):
-                        min_i = min(refd_tokens)
-                        max_i = max(refd_tokens)
+                        min_i = start + min(refd_tokens)
+                        max_i = start + max(refd_tokens)
                         refd_text = doc[min_i : max_i + 1].text
                     else:
                         refd_text = None
@@ -204,8 +204,8 @@ class ReplaceMatcher:
                     ref = len(pattern_ref) + ref
                     refd_tokens = pattern_ref[ref]
                     if len(refd_tokens):
-                        min_i = min(refd_tokens)
-                        max_i = max(refd_tokens)
+                        min_i = start + min(refd_tokens)
+                        max_i = start + max(refd_tokens)
                         refd_text = doc[min_i : max_i + 1].text
                     else:
                         refd_text = None
@@ -345,7 +345,7 @@ class ReplaceMatcher:
         # assert there aren't more than max_suggestions_count
         # otherwise raise warning and return []
         suggestions_count = (
-            seq(options).map(lambda x: len(x)).reduce(lambda x, y: x * y)
+            seq(options).map(lambda x: len(x)).reduce(lambda x, y: x * y, 1)
         )
 
         if suggestions_count > self.max_suggestions_count:
